# The American Journal of Sports Medicine

[http://ajs.sagepub.com/](http://ajs.sagepub.com/)

**Preventive Effect of Eccentric Training on Acute Hamstring Injuries in Men's Soccer : A**
**Cluster-Randomized Controlled Trial**
Jesper Petersen, Kristian Thorborg, Michael Bachmann Nielsen, Esben Budtz-Jørgensen and Per Hölmich
_Am J Sports Med_ 2011 39: 2296 originally published online August 8, 2011
DOI: 10.1177/0363546511419277

The online version of this article can be found at:
[http://ajs.sagepub.com/content/39/11/2296](http://ajs.sagepub.com/content/39/11/2296)

Published by:

[http://www.sagepublications.com](http://www.sagepublications.com)

On behalf of:

[American Orthopaedic Society for Sports Medicine](http://www.aossm.org)

**Additional services and information for** _**The American Journal of Sports Medicine**_ **can be found at:**

**Email Alerts:** [http://ajs.sagepub.com/cgi/alerts](http://ajs.sagepub.com/cgi/alerts)

**Subscriptions:** [http://ajs.sagepub.com/subscriptions](http://ajs.sagepub.com/subscriptions)

**Reprints:** [http://www.sagepub.com/journalsReprints.nav](http://www.sagepub.com/journalsReprints.nav)

**Permissions:** [http://www.sagepub.com/journalsPermissions.nav](http://www.sagepub.com/journalsPermissions.nav)

[>> Version of Record - Oct 28, 2011](http://ajs.sagepub.com/content/39/11/2296.full.pdf)

[OnlineFirst Version of Record](http://ajs.sagepub.com/content/early/2011/08/06/0363546511419277.full.pdf)                - Aug 8, 2011

[What is This?](http://online.sagepub.com/site/sphelp/vorhelp.xhtml)

[Downloaded from ajs.sagepub.com at UNIV OF VIRGINIA on October 12, 2012](http://ajs.sagepub.com/)

## Preventive Effect of Eccentric Training on Acute Hamstring Injuries in Men’s Soccer

### A Cluster-Randomized Controlled Trial

Jesper Petersen,\* \[y\] MD, PhD, Kristian Thorborg, \[y\] PT, PhD,
Michael Bachmann Nielsen, \[z\] MD, PhD, DMSc, Esben Budtz-Jørgensen, \[§\] MSc, PhD,
and Per Ho¨ lmich, \[y\] MD
Investigation performed at the University of Copenhagen, Copenhagen, Denmark

Background: The incidence of acute hamstring injuries is high in several sports, including the different forms of football.

Purpose: The authors investigated the preventive effect of eccentric strengthening of the hamstring muscles using the Nordic
hamstring exercise compared with no additional hamstring exercise on the rate of acute hamstring injuries in male soccer players.

Study Design: Randomized controlled trial; Level of evidence, 1.

Methods: Fifty Danish male professional and amateur soccer teams (942 players) were allocated to an intervention group (461
players) or a control group (481 players). Players in the intervention group conducted a 10-week progressive eccentric training
program followed by a weekly seasonal program, whereas players in the control group followed their usual training program.
The main outcome measures were numbers of overall, new, and recurrent acute hamstring injuries during 1 full soccer season.

Results: Fifty-two acute hamstring injuries in the control group compared with 15 injuries in the intervention group were registered. Comparing intervention versus the control group, overall acute hamstring injury rates per 100 player seasons were 3.8 versus 13.1 (adjusted rate ratio \[RR\], 0.293; 95% confidence interval \[CI\], 0.150-0.572; P \\ .001). New injury rates per 100 player
seasons were 3.1 versus 8.1 (RR, 0.410; 95% CI, 0.180-0.933; P = .034), whereas recurrent injury rates per 100 player seasons
were 7.1 versus 45.8 (RR, 0.137; 95% CI, 0.037-0.509; P = .003). Number needed to treat \[NNT\] to prevent 1 acute hamstring
injury (new or recurrent) is 13 (95% CI, 9-23) players. The NNT to prevent 1 new injury is 25 (95% CI, 15-72) players, and NNT
to prevent 1 recurrent injury is 3 (95% CI, 2-6) players.

Conclusion: In male professional and amateur soccer players, additional eccentric hamstring exercise decreased the rate of
overall, new, and recurrent acute hamstring injuries.

Keywords: hamstring; strain; prevention; eccentric training

Worldwide, more than 15 million adults play amateur soccer in registered clubs and more than 100 000 soccer players
are professionals. \[15\] A significant number of players experience injuries with subsequent pain, disability, and financial
costs. \[29\] Hamstring muscle injury is the most prevalent
injury in soccer, accounting for 12% to 16% of all inju

\*Address correspondence to Jesper Petersen, MD, PhD, Department
of Orthopaedic Surgery, Amager Hospital, Italiensvej 1, Copenhagen DK2300, Denmark (e-mail: <jesper.petersen@dadlnet.dk>).
yDepartment of Orthopaedic Surgery, Amager Hospital, University of
Copenhagen, Copenhagen, Denmark.
zDepartment of Radiology, Section of Ultrasound, Diagnostic Centre,
Rigshospitalet, University of Copenhagen, Copenhagen, Denmark.
§Department of Biostatistics, Institute of Public Health, University of
Copenhagen, Copenhagen, Denmark.
The authors declared that they have no conflicts of interest in the
authorship and publication of this contribution.

The American Journal of Sports Medicine, Vol. 39, No. 11
DOI: 10.1177/0363546511419277
� 2011 The Author(s)

ries. \[2,11,34\] The incidence of hamstring injuries is 0.5 to 1.5
injuries per 1000 hours of soccer exposure (match and training). \[2,12,19\] In addition to the high incidence, a common problem concerning this injury is the high risk of recurrence. A
recurrence rate of 22% within the first 2 months after the
index injury has been reported, and in Danish professional
soccer, 25% of players with a hamstring injury sustain
a recurrent injury in the following season. \[19,26\]

The functions of the hamstring muscles are hip extension and knee flexion. However, the requirements of the
hamstrings in terms of force, velocity, and power are limited during walking and jogging compared with during
sprinting. \[28\] This is consistent with neuromusculoskeletal
models showing that peak hamstring stretch and force
occur during the late swing phase of the running gait cycle
and that force increases significantly with speed. \[8,32\] The
majority of hamstring injuries in soccer occur while players
are running or sprinting, \[2,34\] and these injuries seem to
occur in the late swing phase, where the hamstring
muscles generate tension while lengthening (eccentric

2296

[Downloaded from ajs.sagepub.com at UNIV OF VIRGINIA on October 12, 2012](http://ajs.sagepub.com/)

Vol. 39, No. 11, 2011 Eccentric Training and Acute Hamstring Injuries in Soccer 2297

Figure 1. Flow of participants through the trial.

contraction) to decelerate knee extension. \[20,28\] Increasing
the eccentric strength of the hamstring muscles, performed
by lengthening the hamstring muscle complex while it is
loaded and contracting, has therefore been proposed as
a method to prevent hamstring injuries. \[7,10,31\]

Brockett et al \[7\] used a simple eccentric hamstring
strength training exercise that has been further developed
by Mjølsnes et al \[22\] and is known as the ‘‘Nordic hamstring
exercise.’’ This exercise, which can be done in the field
without the use of any equipment, has been shown to
increase the eccentric strength in the hamstring muscles
in male professional soccer players. \[22\]

However, contradictory results of the effect of eccentric
hamstring strength training on hamstring injuries have
been found. \[1,4,14,17\] Pooled results for the 3 existing studies
that have used a randomized controlled design \[4,14,17\] (n =
287\) have shown substantial heterogeneity between the
results of the studies (I \[2\] = 62%) and no statistically significant
difference between intervention and control groups (risk
ratio, 0.83; 95% confidence interval \[CI\], 0.26-2.65). \[18\] However, these studies had an insufficient sample size or unsatisfactory compliance with the intervention. Rigorously
conducted and sufficiently powered randomized controlled trials are therefore warranted to determine the effects of, for
instance, eccentric hamstring muscle strengthening on the
rate of acute hamstring injuries. \[18,25\] Therefore, we designed
the first cluster-randomized controlled trial with an adequate
sample size to test whether a 10-week training program using
the Nordic hamstring exercise could lower the incidence of

new and recurrent acute hamstring injuries in the subsequent soccer season, and cause less severe hamstring injuries
compared with no additional hamstring exercise.

MATERIALS AND METHODS

Participants

A total of 116 men’s soccer teams play in the top 5 Danish
soccer divisions. Players in division 1 are full-time professionals, whereas players in division 2 are professionals or
semiprofessionals. Players in divisions 3 through 5 are amateurs. All 116 teams were contacted and informed about the

project. As depicted in Figure 1, 24 teams were ineligible
because they already used eccentric hamstring exercises.
Of the remaining 92 teams, 54 accepted and 24 declined
to participate in the trial. Fourteen teams did not respond
to repeated requests. Players of the first-team squads were
included after giving written informed consent. Players
who joined a team after the start of the trial were not
included. Included players who left a team before the end
of the trial were not excluded. However, these players
only contributed to the analysis in proportion to their participation time.
The trial was revised and approved by the Regional
Ethics Committee (H-A-2007-0062) and was registered
with the Danish Data Protection Agency (2007-41-0275)
and ClinicalTrials.gov (NCT00557050).

[Downloaded from ajs.sagepub.com at UNIV OF VIRGINIA on October 12, 2012](http://ajs.sagepub.com/)

2298 Petersen et al The American Journal of Sports Medicine

Randomization

To reduce potential confounding attributable to different
exposure times and playing intensity, all participating
teams were stratified according to playing level before
they were randomized. Because of the organization of the
Danish soccer divisions, all divisions below the secondbest division are divided according to geographical location. Therefore, teams from the 3 lowest divisions were further stratified according to geographic location before
the randomization procedure. We found it necessary to
cluster-randomize using teams as the unit of cluster,
because of the risk of contamination of the intervention
program if individual randomization was used.
An independent research assistant did the randomization procedure by drawing a sealed, opaque envelope containing a team name followed by drawing another sealed,
opaque envelope containing the allocation group (intervention or control) for that particular team. The numbers of
envelopes containing the allocation group were adjusted
to match the number of teams in the particular stratification level and, in cases of an unequal number of teams, the
envelopes were adjusted to 1 extra envelope to secure the
1:1 ratio of intervention and control teams.
The procedure was done in December 2007 to ensure that
the coaches involved were informed regarding the allocation
before the start of the 2008 season. In this manner the
coaches in the intervention teams were able to incorporate
the Nordic hamstring exercise in the preparation and planning of the training sessions for the upcoming season.
Players in the teams were not informed about the project and group allocation until they started their first training session in 2008. This was decided because
a considerable number of players are known to transfer
between clubs in December.

Blinding

The trial was conducted as an open trial. Consequently,
the person responsible for the day-to-day running of the
project, medical staff within the teams, and all players
were aware of group allocation.

Study Period

The playing season in Denmark starts in July or August
and ends in June in the following year. In the 6- to 8week preseason period from June to July/August, most
teams are having a vacation for 2 to 3 weeks. The playing
season includes a midseason competition break from
December to March that divides the first and second halves

of the playing season. In this midseason break, most teams
have a vacation for 2 to 3 weeks.
The 10-week intervention program was introduced in
the midseason break because this is the only time of the
year in which this unaccustomed exercise does not conflict
with the competitive season. The injury registration began
when the participating teams started their first training
session in 2008 (January/February) and ended when the
teams ended their last training session in 2008

(December). Hence, the injury registration period consisted
of the midseason break and second half of the 2007-2008

playing season combined with the preseason and first
half of the 2008-2009 playing season, which equals all
risk periods during a full 12-month season.
The trial was conducted between January 7, 2008, and
December 12, 2008, with follow-up of the last injury until
January 14, 2009.

Baseline and Injury Registration

When the participating teams started their first training session in 2008, all players (n = 942) reported baseline information using a report form in accordance with the
recommendation from the Injury Consensus Group under
the auspices of the FIFA (Fe´de´ration Internationale de Football Association) Medical Assessment and Research Centre. \[16\]

The data included in the analysis were playing position, age,
and details of hamstring injuries during the last 12 months.
The team’s physiotherapist or medical staff were given
standardized instructions regarding injury definition and
collected details of all hamstring injuries in the period
from the first training session in 2008 until the team ended
their last session in 2008. A standardized injury registration
form designed for this trial was used. The injury type was
registered so that contusion injuries could be excluded. Furthermore, the time until the injured player returned to full
participation was registered for all players who had timeloss injuries, that is, for players who missed 1 or more training sessions or matches. Recurrence of already recorded
injuries in the registration period was not included to avoid
recording the same injury more than once. All teams were
contacted by e-mail on a monthly basis during the entire
registration period to encourage the responsible personnel
to register all acute hamstring injuries. To further increase
the compliance of injury registration, all injured players
were offered a free ultrasound examination of the injured
thigh within 7 days. Ultrasound examination was not
used to verify the clinical diagnosis because a great number
of ‘‘characteristic’’ hamstring injuries are known to be undetectable with this imaging modality. \[9\] Therefore it was
decided in advance not to use the results of the ultrasound
examinations in the data analysis.

Intervention

All teams in the intervention and control groups followed
their usual training program. In addition, the teams in the
intervention group performed 27 sessions of the Nordic hamstring exercise in a 10-week period during the midseason
break (Figure 2). The Nordic hamstring exercise is a partner
exercise. The athlete starts in a kneeling position, with his
torso from the knees upward held rigid and straight. A training partner applies pressure to the athlete’s heels/lower legs
to ensure that the feet stay in contact with the ground
throughout the movement. The athlete then attempts to
resist a forward-falling motion using his hamstring muscles
to maximize loading in the eccentric phase. The participants
were asked to brake the forward fall for as long as possible
using the hamstrings. The athletes were asked to use their

[Downloaded from ajs.sagepub.com at UNIV OF VIRGINIA on October 12, 2012](http://ajs.sagepub.com/)

Vol. 39, No. 11, 2011 Eccentric Training and Acute Hamstring Injuries in Soccer 2299

TABLE 1

Training Protocol for the Nordic Hamstring Exercise

Week Sessions Per Week Sets and Repetitions

1 1 2 3 5

2 2 2 3 6

3 3 3 3 6-8

4 3 3 3 8-10

5-10 3 3 sets, 12-10-8 reps
101 1 3 sets, 12-10-8 reps

arms and hands to buffer the fall, let the chest touch the surface, and immediately get back to the starting position by
pushing with their hands to minimize loading in the concentric phase. \[22\] The exercise was conducted during regular
training sessions and players were supervised by their (physical) coach, who was informed about the exercise orally and
had received written descriptions and illustrations of the
exercise. The team coaches decided when the exercise was
performed during the training session but they were advised
not to use the Nordic hamstring exercise before a proper
warm-up program. The teams followed the training protocol
presented in Table 1. After the start of the second half of the
2007-2008 playing season (spring 2008), the exercise was
conducted once a week with 3 sets of 12, 10, and 8 repetitions,
respectively. However, the exercise was not conducted during
the vacation period in the preseason (2-3 weeks). Compliance
of the training program and adverse effects were registered
for each team on a weekly basis by contact with the coaches
during the 10-week training period.

Definitions

The outcome of interest was the occurrence of an acute hamstring injury. In accordance with the general injury definition and recommendation by FIFA, a hamstring injury was
defined as any acute-occurring physical complaint in the
region of the posterior thigh sustained during a soccer match
or training, irrespective of the need for medical attention or
time loss from soccer activities. \[16\] An injury was recorded as
a new injury unless an injured player had reported a similar
injury at the same site at baseline, that is, during the 12month period prior to the trial. In the latter case, the injury
was recorded as a recurrent injury. Recurrence after an
already recorded injury was not registered.
A player was defined as injured until he returned to full
participation in team training and was available for match
selection. The medical staff, in consultation with the player,
assessed when an injured player could return to full participation and be available for match selection. For players with
time-loss injuries, the number of days that elapsed from the
date of injury (day 0) to the date of the player’s return to full
participation was used to calculate the injury severity.

Statistical Analysis

The incidence of hamstring injuries in Danish professional
soccer was estimated at 14% based on data from Danish

Figure 2. The Nordic hamstring exercise.

men’s professional soccer teams. \[26\] We estimated that the
cluster effects for club randomization gave an inflation factor of 1.19 based on a mean cluster size of 20 and an intracluster correlation coefficient (r) of 0.01. \[13\] To achieve 80%
power with a significance level of 5% to detect a relative
risk reduction of 50% and a dropout rate of 20%, a sample
size of 428 players in each group was needed. Our aim was
to include a total of 1000 players in 50 teams.
We used cluster-specific statistical methods because
clubs, and not players, were randomized. Data were entered
into a Microsoft Excel 2007 (Microsoft, Redmond, Washington) spreadsheet and were analyzed with the SAS software
version 9.1 (SAS Institute Inc, Cary, North Carolina).
An injured player was not excluded from the trial
because he was still at risk of sustaining an injury to the
same or opposite thigh. However, recurrence of already
recorded injuries was not included in the data collection
and hence not analyzed.
Number needed to treat (NNT) was estimated by comparing the proportion of injured players in the intervention
and control groups. The injury rates in the 2 groups were
then compared using Poisson regression analysis. Here
the number of injuries in a given player is assumed to follow a Poisson distribution. The mean in this distribution is

given by the product of injury rate and time at risk. The
injury rate is allowed to depend on covariates, while time
at risk is calculated as the number of days the player participated in the study minus the number of days he was
injured. This analysis appropriately takes into account
the fact that not all players had complete follow-up and
that injured players were not at risk of injury in the period
of rehabilitation. Results of the Poisson regression analysis
are given as rate ratios. Because of the clustering in data,
parameters were estimated using ‘‘generalized estimating
equations’’ that account for intrateam correlation of the
injury risk. \[27\] Age, previous injury, and competition level
are known risk factors of sustaining a hamstring injury. \[3,34\]

Thus, in further analysis, the initial model was adjusted
for the players’ age, competition level, and a covariate indicating whether the players had had a previous hamstring
injury. This analysis was conducted to avoid the possibility

[Downloaded from ajs.sagepub.com at UNIV OF VIRGINIA on October 12, 2012](http://ajs.sagepub.com/)

2300 Petersen et al The American Journal of Sports Medicine

TABLE 2
Characteristics of the Cohort at the Beginning of the Trial \[a\]

Characteristic Intervention Group (n = 461) Control Group (n = 481) P Value

Position

Goalkeeper 38 (8.2) 41 (8.5) .88
Defender 134 (29.1) 139 (28.9) .95
Midfielder 147 (31.9) 143 (29.7) .47
Forward 76 (16.5) 77 (16.0) .84
Alternating 66 (14.3) 81 (16.8) .29
Age in years, mean (SD) 23.0 (4.0) 23.5 (4.0) .75
Previous hamstring injury \[b\] 49 (10.6) 54 (11.2) .77
Matches played per team, mean (SD) 29.5 (0.90) 29.5 (1.16) .81

aValues are expressed as number (%) unless stated otherwise. SD, standard deviation.
bWithin 1 year before the trial.

of bias caused by small differences between the 2 groups in
the distribution of their background characteristics. We
then compared the injury rates in the 10-week midseason
period in a Poisson regression analysis restricted to injuries and time at risk in that period. We also compared
the rate of new injuries between the 2 groups. This was
done by comparing the number of injuries and time at
risk only in players who did not have a previous injury.
To compare the risk of recurrence, we restricted the data
to players who had a hamstring injury in the season before
the trial. In a Poisson regression model, we then explored
how the recurrence rate varied between groups. Finally,
we compared the 2 groups with respect to the length of
time players were injured. This was done in a regression
model with age as an additional covariate. Intrateam correlation was taken into account in a so-called mixed model
by allowing residual terms in players from the same team
to be correlated.
The level of significance was set at P \\ .05.

RESULTS

Fifty-four teams accepted and 24 teams declined to participate in the trial. The decliners were teams from all geographical locations and competition levels. A total of 54
teams were included and randomly assigned to an intervention group (26 teams) or a control group (28 teams).
Of the 54 teams that originally were enrolled in the trial,
4 teams withdrew before inclusion of individual players.
It was therefore not possible to include data concerning
these 4 teams in the analyses. Three of the teams that
withdrew were assigned to the intervention group and 1
team was assigned to the control group. Hence, the intervention and control groups consisted of 23 teams (461 players) and 27 teams (481 players), respectively. Fifty-six
players in 3 teams in the intervention group were professionals (division 1 or 2) whereas 405 players in 20 teams
were amateurs (divisions 3-5). The corresponding numbers
in the control group were 62 professional players in 3
teams and 419 amateur players in 24 teams). Figure 1
shows the trial profile. Baseline characteristics of the
groups were similar (Table 2) and the distribution of

professional and amateur teams in the 2 groups were not
significantly different (P = .91).
The mean injury registration period for the 50 teams
was 318 days (range, 283-341 days).
The total number of dropouts was 79 (8%) players (36
players from the intervention group and 43 players from
the control group corresponding to 8% and 9%, respectively).
All dropouts occurred in the preseason period. Reasons for
dropping out were transfer or stop of active career. None
ended their active career because of a hamstring injury.
The teams in the intervention group performed a mean
of 91% of the 27 intended training sessions (mean, 24.6;
standard deviation \[SD\], 2.3; range, 18-27 sessions).
A total of 67 acute hamstring injuries (44 new and 23
recurrent injuries) in 67 players were registered, with 15
injuries in the intervention group (12 new and 3 recurrent
injuries) and 52 injuries in the control group (32 new and
20 recurrent injuries) (Table 3). Nine of 15 (60%) injuries
in the intervention group occurred within the 10-week
training period, whereas the corresponding number in
the control group was 12 of 52 (23%) injuries. Controls
showed a higher injury rate in the preseason period
(adjusted rate ratio \[RR\], 1.76; 95% CI, 0.54-5.67) but
this effect was not statistically significant (P = .35).
No injuries occurred during conduction of the Nordic
hamstring exercise.
Recurrent injuries occurred 2 to 20 months (median, 12
months) after the index injury. Comparing intervention
versus control groups (Table 3), overall hamstring injury
rates were significantly lower in the intervention group
(RR, 0.293; 95% CI, 0.150-0.572; P \\ .001). This difference
was based on both significantly lower injury rates regarding new injuries (RR, 0.410; 95% CI, 0.180-0.933; P = .034)
and recurrent injuries (RR, 0.137; 95% CI, 0.037-0.509; P =
.003). The NNT to prevent 1 overall hamstring injury, be it
a new or recurrent injury, is 13 (95% CI, 9-23) players. The
NNT to prevent 1 new injury is 25 (95% CI, 15-72) players
and NNT to prevent 1 recurrent injury is 3 (95% CI, 2-6)
players.
Injury severity in the 2 groups was assessed by days of
absence from soccer. In the intervention group, the 15 injuries resulted in a total of 454 days absence from soccer
(mean, 30.3; SD, 18.3; median, 22; range, 7-64 days per

[Downloaded from ajs.sagepub.com at UNIV OF VIRGINIA on October 12, 2012](http://ajs.sagepub.com/)

Vol. 39, No. 11, 2011 Eccentric Training and Acute Hamstring Injuries in Soccer 2301

TABLE 3
Acute Hamstring Injuries in Intervention Versus Control Groups \[a\]

Unadjusted
Rate Ratio

(95% CI)

Injury Rate
Per 100

Player NNT
Seasons (95% CI)

Adjusted
Rate Ratio

(95% CI) P Value

No. of

Injury Type Allocation Group Injuries

Player
Seasons

at Risk

Total Intervention (n = 461) 15 390 3.8 13 (9-23) 0.292 (0.136-0.631) 0.293 \[b\] (0.150-0.572) .001
Control (n = 481) 52 396 13.1
New Intervention (n = 461) 12 348 3.1 25 (15-72) 0.380 (0.150-0.965) 0.410 \[c\] (0.180-0.933) .034
Control (n = 481) 32 352 8.1
Recurrent \[d\] Intervention (n = 49) 3 42.0 7.1 3 (2-6) 0.156 (0.046-0.525) 0.137 \[c\] (0.037-0.509) .003
Control (n = 54) 20 43.7 45.8

aNNT, number needed to treat; CI, confidence interval.
bRate ratio adjusted for age of players, competition level, and previous injury.
cRate ratio adjusted for age of players and competition level.
dRecurrence of injuries sustained in the 12-month period prior to the trial.

injury). Of 52 injuries in the control group, 51 could be
evaluated according to severity. These 51 injuries resulted
in a total of 1344 days’ absence from soccer (mean, 26.4;
SD, 19.5; median, 21; range, 4-89 days per injury). Injury
severity for the single player in the control group with
missing data was estimated to 0 days in the Poisson analysis in order to use a conservative approach. After adjustment for age, the mean injury period in the control group
was 8.2 days shorter than in the intervention group, but
this difference was not statistically significant (P = .16).
Eccentric exercise is known to result in delayed-onset
muscle soreness. \[22\] Delayed-onset muscle soreness was
reported by most players in the intervention group during
the first weeks of the training program. Besides this, no
adverse events were reported.

DISCUSSION

This is the first cluster-randomized controlled trial documenting that it is possible to reduce the incidence of hamstring injuries in professional and amateur soccer
significantly by completing a training program that focuses
on increasing eccentric hamstring muscle strength. The
training program is able to reduce the injury rate of new
injuries by more than 60% and an important clinical finding of this trial is that the intervention is highly effective in
reducing the rate of recurrent injuries, which was reduced
by approximately 85%. No beneficial effect on the severity
of hamstring injuries when completing the training program was documented.

Methodologic Considerations

Strengths of this trial are the use of a randomized design
and the inclusion of a large number of participants. In contrast to other studies concerning hamstring injury prevention, \[14,17\] the team compliance of the intervention was very
good, with an average of 91% of the intended training sessions performed during the 10-week midseason period.
However, compliance of the intervention after the first 10

weeks was not recorded, which is a limitation of the present trial. The use of a clear injury definition that made
injury registration independent of a clinical assessment,
combined with the regular contact to the participating
teams, presumably resulted in a minimum of missed injuries and is considered a strength of the trial.
Another strength is to exclude recurrence of already
recorded injuries. The risk of recurrence after a hamstring
injury is high, and it has been shown in Australian Rules
football that more than one-third of all recurrent hamstring injuries occur in the first week after the final rehabilitation day. \[19,24,26\] Recording recurrent injuries of an
already recorded injury would have tended to magnify
the difference between groups and thereby could have
resulted in a false significant difference. By restricting
the injury registration to new injuries only, we avoided
overestimating the effect of the intervention.
Blinding of a nonpharmacologic trial can be difficult to
achieve. \[5,6\] We did not find it possible to introduce a convincing
sham training program that could have led the players in the
control group to believe that they performed a hamstring
injury preventive exercise. The fact that this trial was conducted as an open study with no blinding of the study participants is a limitation that potentially introduced bias.
However, Wood et al \[33\] have shown that the use of an objective outcome, defined as an outcome that cannot be influenced
by investigators’ judgment, minimizes the risk of introducing
bias attributable to group allocation in open studies. The outcome of interest in the present trial was acute events. Most
likely an acute injury cannot be neglected by a player in
the belief that he is protected from injuries because of the
exercise program. Injuries were registered and reported by
the medical personnel within the teams and the person
responsible for the day-to-day running of the project therefore
had no influence on injury reporting. Hence, we consider the
injury reporting an objective outcome, and do not believe that
this issue has biased the results notable. Furthermore, all
analyses were conducted blinded to allocation groups.
In this trial, we reported the number of injuries independent of exposure time, which is a limitation of the trial
because of potential dissimilar exposure in the 2 groups.

[Downloaded from ajs.sagepub.com at UNIV OF VIRGINIA on October 12, 2012](http://ajs.sagepub.com/)

2302 Petersen et al The American Journal of Sports Medicine

However, exposure time in general is not synonymous with
time at risk for incurring an injury. First of all, the generally used term ‘‘1000 exposure hours’’ is not similar in
a division 1 and a division 5 team as quality and intensity
of soccer play depends on the competition level. \[23\] Secondly,
various ‘‘soccer exposures,’’ for instance recovery training,
technical training, and strength training, do not imply
a risk of incurring an acute hamstring injury. Therefore,
a detailed evaluation of exposure would not only involve
individual registration of playing/training time but also
include registration of individual activity and intensity
by GPS (global positioning system), video, heart rate monitoring, and so forth. Then only high-risk activities (highspeed running or sprinting) should be registered as risk
exposure. This approach is not feasible in a large-scale randomized controlled trial such as the present trial. Instead,
we stratified all participating teams according to competition level (5 levels) before they were randomized. This procedure sought to ensure that teams within each
stratification layer in the intervention group and control
group had approximately the same exposure time at a similar intensity regarding both training and match play.
The majority of injuries (9 of 15) in the intervention
group occurred in the 10-week training period in the preseason, whereas 12 of 52 injuries in the control group
occurred in the same period. Since the amount of injuries
in the 2 groups were similar in the first period of the study,
it seems that players in the intervention group were not at
increased risk of injury during the training period, and
that they had to complete a number of training sessions
to gain the injury preventive effect.

Generalizability of Results

The results of this trial are in accordance with the quasiexperimental study by Arnason et al, \[1\] who reported
a 65% lower injury incidence in a group of athletes completing a training program consisting of warm-up stretching, flexibility training, and the Nordic hamstring exercise
compared with warm-up stretching and flexibility training
alone. This indicates that the preventive effect is solely
a result of the Nordic hamstring exercise. In general, the
lack of effect of stretching before exercise on muscle injury
prevention has been shown. \[30\] These findings might be
attributable to the fact that eccentric training, and not
stretching, alters the mechanical properties of the
hamstrings. \[7,21\]

In this study, 50 of 116 teams from the 5 best competition levels participated. The reasons given by the teams
for declining participation in the trial were primarily
a fear of low compliance with the training intervention
because they were uncertain about their head coach for
the upcoming season. Other reasons were concerns about
the amount of time demanded by the training program
and fears that participating in the trial would diminish
the players’ concentration on the impending soccer season.
These issues reflect some of the problems concerning scientific studies in elite sports. Even though decliners theoretically may differ with regard to fitness and training levels,
we do not believe that this has influenced the results of this

trial. We are therefore convinced that the findings in this
trial are valid for male professional and amateur soccer
players. Whether the results can be generalized to women,
other age groups, or to other sports is not known.

Future Implications

The perspective of this trial is that future recommendations concerning hamstring injury prevention in soccer
should focus on eccentric strengthening of the hamstring
muscles. The fact that the Nordic hamstring exercise is
easy to perform, is not a big time-consumer, and can be
done without the use of any additional equipment allows
the exercise to be implemented as a general exercise in
most soccer training programs. However, some coaches
might only want to use the exercise for players at particularly high risk of sustaining a hamstring injury and not for
the entire squad. In that case, the present hamstring exercise program can be highly recommended, since the preventive effect is particularly good in players with
previous hamstring injuries.

ACKNOWLEDGMENT

The authors thank the participating clubs and players for
their time and trouble during the trial. We are very grateful for a critical revision of the draft by Christian Gluud,
MD, DMSc, at the Copenhagen Trial Unit, Centre for Clinical Intervention Research, Rigshospitalet, Copenhagen
University Hospital, Denmark.

REFERENCES

1. Arnason A, Andersen TE, Holme I, Engebretsen L, Bahr R. Prevention
   of hamstring strains in elite soccer: an intervention study. Scand J
   Med Sci Sports. 2008;18:40-48.
1. Arnason A, Gudmundsson A, Dahl HA, Johannsson E. Soccer injuries
   in Iceland. Scand J Med Sci Sports. 1996;6:40-45.
1. Arnason A, Sigurdsson SB, Gudmundsson A, Holme I, Engebretsen
   L, Bahr R. Risk factors for injuries in football. Am J Sports Med.
   2004;32:5S-16S.
1. Askling C, Karlsson J, Thorstensson A. Hamstring injury occurrence
   in elite soccer players after preseason strength training with eccentric
   overload. Scand J Med Sci Sports. 2003;13:244-250.
1. Boutron I, Moher D, Altman DG, Schulz KF, Ravaud P. Extending the
   CONSORT statement to randomized trials of nonpharmacologic
   treatment: explanation and elaboration. Ann Intern Med.
   2008;148:295-309.
1. Boutron I, Tubach F, Giraudeau B, Ravaud P. Blinding was judged
   more difficult to achieve and maintain in nonpharmacologic than
   pharmacologic trials. J Clin Epidemiol. 2004;57:543-550.
1. Brockett CL, Morgan DL, Proske U. Human hamstring muscles adapt
   to eccentric exercise by changing optimum length. Med Sci Sports
   Exerc. 2001;33:783-790.
1. Chumanov ES, Heiderscheit BC, Thelen DG. The effect of speed and
   influence of individual muscles on hamstring mechanics during the
   swing phase of sprinting. J Biomech. 2007;40:3555-3562.
1. Connell DA, Schneider-Kolsky ME, Hoving JL, et al. Longitudinal
   study comparing sonographic and MRI assessments of acute and
   healing hamstring injuries. AJR Am J Roentgenol. 2004;183:975-984.
1. Croisier JL. Factors associated with recurrent hamstring injuries.
   Sports Med. 2004;34:681-695.

[Downloaded from ajs.sagepub.com at UNIV OF VIRGINIA on October 12, 2012](http://ajs.sagepub.com/)

Vol. 39, No. 11, 2011 Eccentric Training and Acute Hamstring Injuries in Soccer 2303

11. Ekstrand J, Hagglund M, Walden M. Injury incidence and injury patterns in professional football: the UEFA injury study. Br J Sports Med.
    2011;45:553-558.
01. Ekstrand J, Timpka T, Hagglund M. Risk of injury in elite football
    played on artificial turf versus natural grass: a prospective two-cohort
    study. Br J Sports Med. 2006;40:975-980.
01. Emery CA. Considering cluster analysis in sport medicine and injury
    prevention research. Clin J Sport Med. 2007;17:211-214.
01. Engebretsen AH, Myklebust G, Holme I, Engebretsen L, Bahr R. Prevention of injuries among male soccer players: a prospective, randomized intervention study targeting players with previous injuries
    or reduced function. Am J Sports Med. 2008;36:1052-1060.
01. Fe´ de´ ration Internationale de Football Association (FIFA). FIFA Big
    Count 2006: 270 million people active in football. <http://www>
    .fifa.com/mm/document/fifafacts/bcoffsurv/bigcount.statspackage\_
    7024.pdf. Accessed November 26, 2009.
01. Fuller CW, Ekstrand J, Junge A, et al. Consensus statement on injury
    definitions and data collection procedures in studies of football (soccer) injuries. Scand J Med Sci Sports. 2006;16:83-92.
01. Gabbe BJ, Branson R, Bennell KL. A pilot randomised controlled trial
    of eccentric exercise to prevent hamstring injuries in community-level
    Australian football. J Sci Med Sport. 2006;9:103-109.
01. Goldman EF, Jones DE. Interventions for preventing hamstring injuries. Cochrane Database Syst Rev. 2010;(1):CD006782.
01. Hagglund M, Walden M, Ekstrand J. Previous injury as a risk factor
    for injury in elite football: a prospective study over two consecutive
    seasons. Br J Sports Med. 2006;40:767-772.
01. Heiderscheit BC, Hoerth DM, Chumanov ES, Swanson SC, Thelen
    BJ, Thelen DG. Identifying the time of occurrence of a hamstring
    strain injury during treadmill running: a case study. Clin Biomech
    (Bristol, Avon). 2005;20:1072-1078.
01. Magnusson SP, Simonsen EB, Aagaard P, Dyhre-Poulsen P,
    McHugh MP, Kjaer M. Mechanical and physical responses to
    stretching with and without preisometric contraction in human skeletal muscle. Arch Phys Med Rehabil. 1996;77:373-378.
01. Mjolsnes R, Arnason A, Osthagen T, Raastad T, Bahr R. A 10-week
    randomized trial comparing eccentric vs. concentric hamstring

strength training in well-trained soccer players. Scand J Med Sci
Sports. 2004;14:311-317.
23\. Mohr M, Krustrup P, Bangsbo J. Match performance of high-standard soccer players with special reference to development of fatigue.
J Sports Sci. 2003;21:519-528.
24\. Orchard J, Best TM. The management of muscle strain injuries: an
early return versus the risk of recurrence. Clin J Sport Med.
2002;12:3-5.
25\. Petersen J, Holmich P. Evidence based prevention of hamstring injuries in sport. Br J Sports Med. 2005;39:319-323.
26\. Petersen J, Thorborg K, Nielsen MB, Holmich P. Acute hamstring injuries in Danish elite football: a 12-month prospective registration study
among 374 players. Scand J Med Sci Sports. 2010;20:588-592.
27\. Pickles A. Generalized estimating equations. In: Armitage P, Colton
T, eds. Encyklopedia of Biostatistics. 2nd ed. Chichester, UK: John
Wiley & Sons; 2005;2074-2085.
28\. Schache AG, Wrigley TV, Baker R, Pandy MG. Biomechanical
response to hamstring muscle strain injury. Gait Posture. 2009;29:
332-338.

29. Schmikli SL, Backx FJ, Kemler HJ, van Mechelen W. National survey
    on sports injuries in the Netherlands: target populations for sports
    injury prevention programs. Clin J Sport Med. 2009;19:101-106.
01. Shrier I. Stretching before exercise does not reduce the risk of local
    muscle injury: a critical review of the clinical and basic science literature. Clin J Sport Med. 1999;9:221-227.
01. Stanton P, Purdham C. Hamstring injuries in sprinting: the role of
    eccentric exercise. J Orthop Sports Phys Ther. 1989;10:343-349.
01. Thelen DG, Chumanov ES, Best TM, Swanson SC, Heiderscheit BC.
    Simulation of biceps femoris musculotendon mechanics during the
    swing phase of sprinting. Med Sci Sports Exerc. 2005;37:1931-1938.
01. Wood L, Egger M, Gluud LL, et al. Empirical evidence of bias in treatment effect estimates in controlled trials with different interventions

and outcomes: meta-epidemiological study. BMJ. 2008;336:601-605.
34\. Woods C, Hawkins RD, Maltby S, Hulse M, Thomas A, Hodson A.
The Football Association Medical Research Programme: an audit of
injuries in professional football–analysis of hamstring injuries. Br J
Sports Med. 2004;38:36-41.

For reprints and permission queries, please visit SAGE’s Web site at <http://www.sagepub.com/journalsPermissions.nav>

[Downloaded from ajs.sagepub.com at UNIV OF VIRGINIA on October 12, 2012](http://ajs.sagepub.com/)
